<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Informazioni su SMTube</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Traduttori</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>Browser YouTube%1  per SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Versione: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Edizione Portatile</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Compilato con Qt %1 (versione in uso: %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Per ulteriori aggiornamenti visita il sito:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>Molte persone hanno già contribuito alla traduzione di SMTube,</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>se desideri contribuire con la tua traduzione o aiutarci con la traduzione di SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Visita il sito %1 </translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Persone coinvolte nel team di Transifex</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="112"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="115"/>
        <source>Navigation</source>
        <translation>Navigazione</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="123"/>
        <source>Zoom +</source>
        <translation>Zoom +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="127"/>
        <source>Zoom -</source>
        <translation>Zoom -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="131"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="134"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Navigazione</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="146"/>
        <source>&amp;View</source>
        <translation>&amp;Mostra</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="147"/>
        <source>Toolbar</source>
        <translation>Barra strumenti</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="151"/>
        <source>Statusbar</source>
        <translation>Barra di stato</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="155"/>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni...</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="163"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="167"/>
        <source>&amp;Update YouTube playback support</source>
        <translation>&amp;Aggiorna supporto YouTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="169"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation>&amp;Installa / Aggiorna supporto YouTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="175"/>
        <source>&amp;About SMTube</source>
        <translation>Informazioni su &amp;SMTube...</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="296"/>
        <source>Download video using an external service</source>
        <translation>Scarica video tramite servizio esterno</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="297"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="524"/>
        <source>No video found</source>
        <translation>Nessun video trovato</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="525"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Non è stato possibile trovare l&apos;URL di questo video</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="282"/>
        <source>Loading... %1%</source>
        <translation>Caricamento... %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation>Scaricamento...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation>Connessione a %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation>Il codice di YouTube è stato aggiornato con successo.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation>Versione installata: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation>Successo</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation>Impossibile salvare %1.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation>Si è verificato un errore durante lo scaricamento del file: 
%1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation>%1 non è stato in grado di comunicare, non funziona oppure non è stato installato correttamente.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Non è stato possibile trovare l&apos;URL di questo video.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation>Probabilmente è necessario aggiornare youtube-dl.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <location filename="../codedownloader.cpp" line="208"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation>Per riprodurre i video da YouTube, %1 necessita di una applicazione esterna chiamata youtube-dl.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation>Questo componente ha bisogno di essere aggiornato frequentemente.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation>Puoi aggiornarlo semplicemente reinstallando SMPlayer. Il programma di installazione scaricherà ed installerà la versione più recente.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation>Installa / Aggiorna supporto YouTube</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="209"/>
        <source>%1 can download and install this application for you.</source>
        <translation>%1 può scaricare ed installare questa applicazione per te.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="210"/>
        <source>It will be downloaded from the official website and installed in %1.</source>
        <translation>Verrà scaricato dal sito ufficiale ed installato in %1.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="211"/>
        <source>Would you like to proceeed?</source>
        <translation>Si desidera procedere?</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="215"/>
        <location filename="../codedownloader.cpp" line="218"/>
        <source>Install YouTube support?</source>
        <translation>Installare il supporto YouTube?</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>&amp;Generale</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation>A&amp;ggiungi...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="166"/>
        <source>&amp;Players</source>
        <translation>&amp;Lettori</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="214"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="179"/>
        <source>Up</source>
        <translation>Sposta in alto</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Riproduzione</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>&amp;Qualità:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation>Siti</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation>&amp;Sito:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation>Mo&amp;difica...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation>Ca&amp;ncella</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="225"/>
        <source>Delete</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="249"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="262"/>
        <source>A&amp;dd predefined players</source>
        <translation>A&amp;ggiungi lettori predefiniti</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="298"/>
        <source>&amp;Interface</source>
        <translation>&amp;Interfaccia</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="306"/>
        <source>&amp;Style:</source>
        <translation>&amp;Stile:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="342"/>
        <source>Font:</source>
        <translation>Font:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="356"/>
        <source>C&amp;hange...</source>
        <translation>M&amp;odifica...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Scarica video tramite servizio &amp;esterno</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="190"/>
        <source>Down</source>
        <translation>Sposta in basso</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="79"/>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Clicca per seleziona un file o una cartella</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>Apri su &amp;YouTube</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>&amp;Salva link...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>Copia &amp;link nella clipboard</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Apri link in questa finestra</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>&amp;Copia testo nella clipboard</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>Apri link in &amp;nuova finestra</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>&amp;Riproduci con</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation>Riproduci &amp;audio con</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>Ri&amp;produci con %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="144"/>
        <source>Play &amp;audio with %1</source>
        <translation>Riproduci &amp;audio con %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="151"/>
        <source>Play video with a &amp;web browser</source>
        <translation>Riproduci video sul &amp;browser</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Modifica Lettore</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nome:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>&amp;Eseguibile:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Parametri:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Questo lettore supporta vari portali &amp;video</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Questo lettore può visualizzare le TV &amp;online</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>Qualità &amp;preferita:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>Aggiungi al &amp;menu:</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Video e audio</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Predefinita</translation>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation>Modifica Sito</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nome:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation>&amp;Home page URL:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation>&amp;Ricerca URL:</translation>
    </message>
</context>
</TS>
